<?php

use DMG\Sailthru_Content_API\Settings;

/**
 * Class Test_Sailthru_Content_API_Settings.
 *
 * Unit tests for Sailthru Content API Settings.
 *
 * @covers \DMG\Sailthru_Content_API\Settings
 * @group  dmg-sailthru-content-api
 * @group  dmg-sailthru-content-api-settings
 */
class Test_Sailthru_Content_API_Settings extends WP_UnitTestCase {

	/**
	 * Set up.
	 */
	function set_up() {
		parent::set_up();
	}

	/**
	 * Tear down.
	 */
	function tear_down() {
		parent::tear_down();
	}

	/**
	 * Test getting the API Key from filter and options.
	 *
	 * @dataProvider auth_values_provider
	 */
	public function test_get_api_key( $expect, $filter_value, $option_value ) {
		if ( $filter_value ) {
			add_filter( 'dmg_sailthru_content_api_auth_key', fn() => $filter_value );
		}

		if ( $option_value ) {
			update_option( Settings::OPTION_API_KEY, $option_value );
		}

		$this->assertSame( $expect, Settings::get_api_key() );
	}

	/**
	 * Test getting the API Secret from filter and options.
	 *
	 * @dataProvider auth_values_provider
	 */
	public function test_get_api_secret( $expect, $filter_value, $option_value ) {
		if ( $filter_value ) {
			add_filter( 'dmg_sailthru_content_api_auth_secret', fn() => $filter_value );
		}

		if ( $option_value ) {
			update_option( Settings::OPTION_API_SECRET, $option_value );
		}

		$this->assertSame( $expect, Settings::get_api_secret() );
	}

	/**
	 * Values for get_api_key() and get_api_secret().
	 */
	function auth_values_provider() {
		return [
			'Option & filter' => [ 'filter-value', 'filter-value', 'option-value' ],
			'Option'          => [ 'option-value', false, 'option-value' ],
			'Filter'          => [ 'filter-value', 'filter-value', false ],
		];
	}
}
